@@ -65,6 +65,7 @@
 #' Note also that an original file, i.e. generated by IDEAS(R) or INSPIRE(R), will never be overwritten.
 #' Otherwise, you will get an error saying that overwriting original file is not allowed.\cr
 #' @param display_progress whether to display a progress bar. Default is TRUE.
+#' @param add_tracking whether to register files' paths and objects' ids in the exported file. Default is TRUE.
 #' @param ... other arguments to be passed.
 #' @details when 'extract_features' is set TRUE, only features stored in binary format will be extracted if found.\cr
 #' If the input 'fileName' is a merged of several files then features will be extracted from these files.\cr
@@ -87,7 +88,8 @@
 ExportToXIF <- function(fileName, write_to, 
                         objects, offsets, fast = TRUE, 
                         extract_features = FALSE, endianness = .Platform$endian, verbose = FALSE, verbosity = 1, 
-                        overwrite = FALSE, display_progress = TRUE, ...) {
+                        overwrite = FALSE, display_progress = TRUE,
+                        add_tracking = TRUE, ...) {
   dots = list(...)
   # check madatory param
   if(missing(fileName)) stop("'fileName' can't be missing")
@@ -99,7 +101,7 @@ ExportToXIF <- function(fileName, write_to,
   }
   args = list(fileName = fileName, write_to = write_to,
               extract_features = extract_features, endianness = endianness, verbose = verbose, verbosity = verbosity, 
-              overwrite = overwrite, display_progress = display_progress)
+              overwrite = overwrite, display_progress = display_progress, add_tracking = add_tracking)
   args = c(args, dots)
   if(length(fileName) > 1) {
     return(do.call(what = mergeXIF, args = args))
