@@ -54,6 +54,30 @@ std::string hpp_getEndian () {
   return out;
 }
 
+// combine Rcpp Vectors
+template <int RTYPE> Rcpp::Vector<RTYPE>
+c_vector_T( const Rcpp::Vector<RTYPE>&x, const Rcpp::Vector<RTYPE>&y) {
+  Rcpp::Vector<RTYPE> out(x.size() + y.size());
+  std::copy(x.begin(), x.end(), out.begin());
+  std::copy(y.begin(), y.end(), out.begin() + x.size());
+  return(out);
+}
+SEXP c_vector( SEXP x, SEXP y) {
+  if((TYPEOF(x) == NILSXP) && (TYPEOF(y) == NILSXP)) return R_NilValue;
+  if(TYPEOF(x) == NILSXP) return y;
+  if(TYPEOF(y) == NILSXP) return x;
+  if(TYPEOF(x) != TYPEOF(y)) Rcpp::stop("c_vector: 'x' and 'y' should have same RTYPE");
+  switch( TYPEOF(x) ) {
+  case NILSXP: return R_NilValue;
+  case LGLSXP: return c_vector_T<LGLSXP>(x, y);
+  case INTSXP: return c_vector_T<INTSXP>(x, y);
+  case REALSXP: return c_vector_T<REALSXP>(x, y);
+  case STRSXP: return c_vector_T<STRSXP>(x, y);
+  case RAWSXP: return c_vector_T<RAWSXP>(x, y);
+  default: Rcpp::stop("c_vector: not supported type in 'x'");
+  }
+}
+
 // Ensures NumericVector is not NULL
 bool nNotisNULL(const Rcpp::Nullable<Rcpp::NumericVector> x_ = R_NilValue) {
   if (x_.isNotNull()) {
@@ -87,6 +111,39 @@ bool lNotisNULL(const Rcpp::Nullable<Rcpp::LogicalVector> x_ = R_NilValue) {
   return false;
 }
 
+//' @title Multiple Pattern Fixed Matching
+//' @name cpp_mpfmatch
+//' @description
+//' String matching with multiple pattern.
+//' @param x,pattern Nullable Rcpp CharacterVector.
+//' @details equivalent of as.logical(sum(unlist(lapply(pattern, grepl, x = x, fixed = TRUE)))).
+//' @return a bool
+//' @keywords internal
+////' @export
+// [[Rcpp::export(rng = false)]]
+bool hpp_mpfmatch(const Rcpp::Nullable<Rcpp::CharacterVector> x = R_NilValue,
+                  const Rcpp::Nullable<Rcpp::CharacterVector> pattern = R_NilValue) {
+  bool found = false;
+  if(x.isNotNull()) {
+    Rcpp::CharacterVector xx(x);
+    if(xx.size() > 0) {
+      std::string str = std::string(xx[0]);
+      if(pattern.isNotNull()) {
+        Rcpp::CharacterVector pat(pattern);
+        for(R_len_t i = 0; i < pat.size(); i++) {
+          if((i % 100) == 0) Rcpp::checkUserInterrupt();
+          std::string p = std::string(pat[i]);
+          if(str.find(p) != std::string::npos) {
+            found = true;
+            break;
+          }
+        }
+      }
+    }
+  }
+  return found;
+}
+
 //' @title Sequence of Strings Matching
 //' @name cpp_seqmatch
 //' @description
@@ -96,7 +153,7 @@ bool lNotisNULL(const Rcpp::Nullable<Rcpp::LogicalVector> x_ = R_NilValue) {
 //' @return the index (starting at 1) when a match has been found. Otherwise 0.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 R_len_t hpp_seqmatch(const Rcpp::StringVector x,
                      const Rcpp::StringVector y) {
   R_len_t i = 0, j = 0, k = 0;
@@ -129,7 +186,7 @@ R_len_t hpp_seqmatch(const Rcpp::StringVector x,
 //' @return a LogicalVector.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 Rcpp::Nullable<Rcpp::LogicalVector> hpp_fast_rowAny(const Rcpp::Nullable<Rcpp::LogicalVector> M_ = R_NilValue) {
   if(!lNotisNULL(M_)) return M_;
   Rcpp::LogicalVector V(M_.get());
@@ -155,7 +212,7 @@ Rcpp::Nullable<Rcpp::LogicalVector> hpp_fast_rowAny(const Rcpp::Nullable<Rcpp::L
 //' @return a LogicalVector.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 Rcpp::Nullable<Rcpp::LogicalVector> hpp_fast_listAny(const Rcpp::Nullable<Rcpp::List> L_ = R_NilValue) {
   if(L_.isNotNull()) {
     Rcpp::List L(L_.get());
@@ -187,7 +244,7 @@ Rcpp::Nullable<Rcpp::LogicalVector> hpp_fast_listAny(const Rcpp::Nullable<Rcpp::
 //' @return a NumericVector.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 Rcpp::NumericVector hpp_fast_range(const Rcpp::Nullable<Rcpp::NumericVector> x_ = R_NilValue) {
   double xmax = R_NegInf, xmin = R_PosInf;
   if(nNotisNULL(x_)) {
@@ -229,7 +286,7 @@ Rcpp::IntegerVector hpp_fast_sample(const R_len_t n = 0,
 //' @param rev bool whether to reverse order or not. Default is false.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 Rcpp::Nullable<Rcpp::IntegerVector> hpp_get_bytes_order (const R_len_t obj = 0,
                                                          const Rcpp::Nullable<Rcpp::IntegerVector> byt_ = R_NilValue,
                                                          const Rcpp::Nullable<Rcpp::IntegerVector> ord_ = R_NilValue,
@@ -269,7 +326,7 @@ Rcpp::Nullable<Rcpp::IntegerVector> hpp_get_bytes_order (const R_len_t obj = 0,
 }
 
 // converts unsigned short to string
-std::string to_string(const uint16_t x) {
+std::string to_string(const double x) {
   std::string out;
   std::ostringstream convert;
   convert << x;
@@ -285,7 +342,7 @@ std::string to_string(const uint16_t x) {
 //' @param by a double used as replacement value. Default is 0.0
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 Rcpp::Nullable<Rcpp::NumericVector> hpp_replace_non_finite(const Rcpp::Nullable<Rcpp::NumericVector> V_ = R_NilValue,
                                                            const double by = 0.0) {
   if(nNotisNULL(V_)) {
@@ -341,7 +398,7 @@ Rcpp::NumericVector hpp_check_range(const Rcpp::NumericVector x) {
 //' @param V named NumericVector of channel display properties containing 'xmin', 'xmax', 'xmid' and 'ymid'.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 double hpp_computeGamma (const Rcpp::NumericVector V) {
   double V_w = V["xmax"], V_m = V["xmid"], V_y = V["ymid"];
   V_w -= V["xmin"];
@@ -357,7 +414,7 @@ double hpp_computeGamma (const Rcpp::NumericVector V) {
 //' @return a string, representing the base64 encoding of x.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 std::string hpp_base64_encode (const Rcpp::RawVector x) {
   R_len_t i = 0, a = x.size() / 3, b = x.size() % 3;
   std::string out;
@@ -395,7 +452,7 @@ std::string hpp_base64_encode (const Rcpp::RawVector x) {
 //' @param image, a [0,1] normalized image matrix or 3D array. If 3D array, 3rd dimension should be of length 1 or 3.
 //' @keywords internal
 ////' @export
-// [[Rcpp::export]]
+// [[Rcpp::export(rng = false)]]
 Rcpp::RawVector hpp_writeBMP (const Rcpp::NumericVector image) {
   if(nNotisNULL(image)) {
     Rcpp::IntegerVector d = image.attr("dim");
